/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only 
* intended for use with Renesas products. No other uses are authorized. This 
* software is owned by Renesas Electronics Corporation and is protected under 
* all applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING 
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT 
* LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE 
* AND NON-INFRINGEMENT.  ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
* TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS 
* ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE 
* FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR 
* ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE 
* BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software 
* and to discontinue the availability of this software.  By using this software, 
* you agree to the additional terms and conditions found by accessing the 
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2015 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/

/***********************************************************************************************************************
* File Name    : r_cg_adc.c
* Version      : 
* Device(s)    : R5F117GCG
* Tool-Chain   : IAR Systems iccrl78
* Description  : This file implements device driver for CMP module.
* Creation Date: 10/01/2015
***********************************************************************************************************************/

/***********************************************************************************************************************
Includes
***********************************************************************************************************************/
#include "r_cg_macrodriver.h"
#include "r_cg_cmp.h"
/* Start user code for include. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */
#include "r_cg_userdefine.h"

/***********************************************************************************************************************
Global variables and functions
***********************************************************************************************************************/
/* Start user code for global. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */

/***********************************************************************************************************************
* Function Name: R_CMP_Create
* Description  : This function initializes the comparator.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_CMP_Create(void)
{
    CMPRES = 0U;                      /* reset release */
    CMPEN  = 1U;                      /* supply CMP clock */

    PMC1 |= 0x10;                     /* Analog input */
    PMC2 |= 0x01;                     /* Analog input */
    PMC3 |= 0x03;                     /* Analog input */

    PM1 |= 0x10;                      /* Input mode */
    PM2 |= 0x01;                      /* Input mode */
    PM3 |= 0x03;                      /* Input mode */

    SPDMD = 1U;                       /* low speed mode */

    COMPMDR = 0x00;                   /* standard mode, comparator disabled */

    COMPFIR = 0x00;                   /* Interrupt request at rising edge, no comparator filter. */

    C0OE = 0U;                        /* VCOUT0 output disable */
    C0IE = 1U;                        /* Comparator 0 interrupt disable */
    C1OE = 0U;                        /* VCOUT1 output disable */
    C1IE = 1U;                        /* Comparator 1 interrupt disable */

    /* Set INTCMP0 low priority */
    CMPPR01 = 1U;
    CMPPR00 = 1U;
    /* Set INTCMP1 low priority */
    CMPPR11 = 1U;
    CMPPR10 = 1U;

    CMPMK0 = 1U;                      /* disable INTCMP0 interrupt */
    CMPIF0 = 0U;                      /* clear INTCMP0 interrupt flag */
    CMPMK1 = 1U;                      /* disable INTCMP1 interrupt */
    CMPIF1 = 0U;                      /* clear INTCMP1 interrupt flag */
    
}

/***********************************************************************************************************************
* Function Name: R_CMP0_Start
* Description  : This function starts the comparator 0.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_CMP0_Start(void)
{
    CMPIF0 = 0U;  /* clear INTCMP0 interrupt flag */
    CMPMK0 = 0U;  /* enable INTCMP0 interrupt */
    C0ENB  = 1U;  /* comparator 0 enabled */
}

/***********************************************************************************************************************
* Function Name: R_CMP1_Start
* Description  : This function starts the comparator 1.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_CMP1_Start(void)
{
    CMPIF1 = 0U;  /* clear INTCMP1 interrupt flag */
    CMPMK1 = 0U;  /* enable INTCMP1 interrupt */
    C1ENB  = 1U;    /* comparator 1 disabled */
}

/***********************************************************************************************************************
* Function Name: R_CMP0_Stop
* Description  : This function stops the AD converter.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_CMP0_Stop(void)
{
    C0ENB = 0U;   /* comparator 0 disabled */
    CMPMK0 = 1U;  /* disable INTCMP0 interrupt */
    CMPIF0 = 0U;  /* clear INTCMP0 interrupt flag */
}


/***********************************************************************************************************************
* Function Name: R_CMP1_Stop
* Description  : This function stops the AD converter.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_CMP1_Stop(void)
{
    C1ENB = 0U;   /* comparator 1 disabled */
    CMPMK1 = 1U;  /* disable INTCMP1 interrupt */
    CMPIF1 = 0U;  /* clear INTCMP1 interrupt flag */
}


/* Start user code for adding. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */
